

% script genTrainingFeatures.m
%
% This script loops through all training images and generates the set
% of feature vectors containing single scale and multiscale information
% Then it all gets saved in trainingFeatures.mat

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Load all training images and extract the feature vectors 
% both association and interaction, as well as the true seg-
% mentation of the training images.

TrainingDir = 'DATA/totalImagesTrain';
files = dir(strcat(TrainingDir,'\*.jpg'));

% set up the directory for known label segmentations.
TrainingLabelDir = 'DATA/totalLabelsTrain';
label_files = dir(strcat(TrainingLabelDir,'\*.tif'));

% Perform calculations for each training image in the training 
% directory.

disp(['Extracting Feature Data .... please wait']);
for i=1:length(files)
	

   currImage = feval('imread',files(i).name,'jpg');


%----------------------------------------------------------------------

  % compute the gradient magnitude and orientation.

  [imGradMag, imGradOrient] = getGradIntensAndOrient(currImage);

%----------------------------------------------------------------------
   % compute the feature vectors for the image

   starttime = cputime;
   [ssFea{i}, msFea{i} ] = getFeatureVectors( imGradMag, imGradOrient);
   endtime = cputime;

   disp(['Image ' num2str(i) ' Run time: ' num2str(endtime-starttime)]);

%------------------------------------------------------------------------
   % Features now extracted, we need to get the correct segmentation for the
   % training data.  Found in Data/totalLabelsTrain

   % load the correct segmentation
   corrLabelsEdgy{i} = feval('imread',label_files(i).name,'tif');
   corrLabelsSmooth{i} = feval('imread',label_files(i+108).name,'tif');

   if isa(corrLabelsEdgy{i}, 'uint8') | isa(corrLabelsEdgy{i}, 'uint16') 
      corrLabelsEdgy{i} = im2double(corrLabelsEdgy{i});
   end
   if isa(corrLabelsSmooth{i}, 'uint8') | isa(corrLabelsSmooth{i}, 'uint16') 
      corrLabelsSmooth{i} = im2double(corrLabelsSmooth{i});
   end
   corrLabels{i} = or(corrLabelsSmooth{i},corrLabelsEdgy{i});
   tmp = -1*(corrLabels{i}==0);
   corrLabels{i} = corrLabels{i}>0;  %convert to 0, 1
   corrLabels{i} = tmp +corrLabels{i};

   % corrLabels is now just a matrix each element correspodns to the 16x16
   % sites.  We want to stretch this out into a vector

end

%------------------------------------------------------------------------
% Feature extraction and correct labelling now complete

  save manMade/trainingFeatures.mat ssFea msFea corrLabels;