function [gradMag, gradOrient] = getGradIntensAndOrient( currImage )

%  This function calculates and returns the intensity and orientation
% of the gradient for an image currImage.  currImage is in the format
% uint8 and must first be converted to gray-scale so an intensity can
% be looked at.
%
% function [gradMag, gradOrient] = getGradIntensAndOrient( currImage )
%

% Author: Tim Rees.
% Date: Nov 20, 2004

%-------------------------------------------------------------------------
% PRE-PROCESSING STEPS

   % Convert the image to gray-scale

   % Basic image transformations to gray scale

   % Transform to a double precision intensity image
   if isa(currImage, 'uint8') 
      currImage = im2double(currImage);
   end

   currGrayIm = rgb2gray(currImage);

   % image is now gray-scale intensity format
%------------------------------------------------------------------------

   % Compute gradient intensity and orientation

   lx=size(currGrayIm,2);
   dummyX = currGrayIm(:,2:lx);
   dummyX(:,lx) = currGrayIm(:,lx-2)+2*(currGrayIm(:,lx-1)-currGrayIm(:,lx-2));

   %now compute the x derivative
   dxIm = dummyX-currGrayIm;
   clear dummyX;

   %now compute the y direction of the gradient
   ly=size(currGrayIm,1);
   dummyY = currGrayIm(2:ly,:);
   dummyY(ly,:) = currGrayIm(ly-2,:)+2*(currGrayIm(ly-1,:)-currGrayIm(ly-2,:));

   %the y component of the gradient is now:
   dyIm = dummyY-currGrayIm;
   clear dummyY;

   % Gradient intensity: vector sum of x and y components
   gradMag = sqrt(dxIm.*dxIm +dyIm.*dyIm);

   % Compute gradient orientation:
   % First ensure no div by zeros
   dummy=(dxIm==0);
   dxIm=10^(-10)*dummy + dxIm;

   gradOrient = dyIm./dxIm;
   gradOrient = atan(gradOrient);

   %orientations now from -pi/2 to pi/2, we want -pi to pi.
   xNeg = dxIm <0;
   yNeg = dyIm <0;
   % if x is neg and y is we subtract pi
   negNeg= xNeg.*yNeg;
   gradOrient = gradOrient - pi*negNeg;
   negXPosY = xNeg.*(1-yNeg);
   gradOrient = gradOrient+pi*negXPosY;
   
   clear dxIm;
   clear dyIm;

