/*

  * This is a mex interface to compute a kernel smoothing

  * I am using this because my kernelSmoother.m function is

  * the major bottleneck in the feature extraction process

  * and all that is really required is a double for-loop.

  *ASSUMPTION the input weighted count vector is a column.

  *NOTE: This function is NOT bullet-proof

  * This function uses exp(-x^2) as the kernel smoother

 */

#include <math.h>
#include "mex.h"

/* the input arguments */
#define DATA       prhs[0]

/* the output array */
#define SM_OUT            plhs[0]


void mexFunction(int nlhs, mxArray *plhs[ ], 
			int nrhs, const mxArray *prhs[ ])
{

	int nBins;   /* the number of bins */
	int i,j;       /* counting index */

	double *smCnts;  /* pointer to smoothed counts */
	double *myData;

	double expTerm;  /* a temp storage value */
	double numer;
	double denom;

	/* Check for sufficient input arguments */
	if (nrhs != 1) 
	{ 
		mexErrMsgTxt("One input arguments required."); 
    } 

	
    nBins = mxGetM(DATA);  /* assume column vector */

	/* Create a array for the return argument */ 
    SM_OUT = mxCreateDoubleMatrix(nBins, 1, mxREAL); 
    
	/* get the pointers to work with */
	smCnts = mxGetPr(SM_OUT);
    
	myData = mxGetPr(DATA);

	
	
	/* apply kernel smoothing to each bin */
	for( i=0; i<nBins; i++)
	{
		smCnts[i]=0;
		numer=0;
		denom=0;
		for(j=0; j<nBins; j++)
		{
			expTerm = exp(-(i-j)*(i-j));
			numer += myData[j]*expTerm;
			denom += expTerm;

		}
		smCnts[i] = numer/denom;
	}
	
}