/*

  * This is a mex interface to compute a weighted histogram

  */

#include "mex.h"

/* the input arguments */
#define DATA        prhs[0]
#define WEIGHTS	     prhs[1]
#define BIN_CENTS    prhs[2]

/* the output array */
#define W_OUT        plhs[0]


void mexFunction(int nlhs, mxArray *plhs[ ], 
			int nrhs, const mxArray *prhs[ ])
{

	int nBins;   /* the number of bins */
	int nData;   /* the number of data points */
	int i,j;       /* counting index */

	double *wp;
	double *myData;
	double *myBinCents;
	double *myWeights;
	double binWidth;

	/* Check for sufficient input arguments */
	if (nrhs != 3) 
	{ 
		mexErrMsgTxt("Three input arguments required."); 
    } 

	nData = mxGetM(DATA); 
    nBins = mxGetM(BIN_CENTS);

	/* Create a array for the return argument */ 
    W_OUT = mxCreateDoubleMatrix(nBins, 1, mxREAL); 
    
	/* get the pointers to work with */
	wp = mxGetPr(W_OUT);
    
	myData = mxGetPr(DATA); 
    myWeights = mxGetPr(WEIGHTS);
	myBinCents = mxGetPr(BIN_CENTS);

	binWidth = 0.5*(myBinCents[1]-myBinCents[0]);

	/* initialize the bin counts */
	for( i=0; i<nBins; i++)
		wp[i]=0.0;

	for( i=0; i<nData; i++)
	{
		j=0;
		while( myData[i] > myBinCents[j]+binWidth )
			j++;
		wp[j] = wp[j]+myWeights[i];

	}
	
	
}
